// java wrapper for vtkContextActor object
//

package vtk;
import vtk.*;

public class vtkContextActor extends vtkProp
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int RenderOverlay_2(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_2(id0); }

  private native long GetContext_3();
  public vtkContext2D GetContext() {
    long temp = GetContext_3();

    if (temp == 0) return null;
    return (vtkContext2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetScene_4();
  public vtkContextScene GetScene() {
    long temp = GetScene_4();

    if (temp == 0) return null;
    return (vtkContextScene)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetScene_5(vtkContextScene id0);
  public void SetScene(vtkContextScene id0)
    { SetScene_5(id0); }

  private native void ReleaseGraphicsResources_6(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_6(id0); }

  public vtkContextActor() { super(); }

  public vtkContextActor(long id) { super(id); }
  public native long   VTKInit();

}
